# -*- coding: UTF-8 -*-
import autopath
from cfg_parser import PermissionParser
from permission import InitPermissions

from os.path import join, dirname
from sets import Set

data= join(dirname(__file__), 'data')

def setup_module(module):
    module.parser = PermissionParser()
    module.parser.parse_file(join(data, 'perm.ini'))

    module.parser2 = PermissionParser()
    module.parser2.parse_file(join(data, 'baseperm.ini'))

    module.permissions = InitPermissions(join(data, 'perm.ini'))


def test_thumbs():
    result  = parser.get_thumbs()
    assert Set(result.keys()) == Set(['google', 'cartable'])

def test_profiles():
    result = parser.get_profiles()
    assert result ==  {'admin': 'administrateur', 'role1': 'Role test1', 'user': 'utilisateur', 'role2': 'Role test2'}

def test_permissions():
    result = parser.get_permissions()
    assert Set(result['admin']) == Set(['google', 'cartable', 'desktop_mail'])
    assert Set(result['role1']) == Set(['google', 'cartable'])
    assert Set(result['user']) == Set( ['google', 'desktop_mail'])
    assert Set(result['role2']) == Set(['google'])

def test_thumbs_obj():
    thumbs = permissions.get_thumbs()
    for th in thumbs.values():
        assert th.name in ['cartable', 'google']

def test_desktop_items():
    desktop_items = permissions.get_desktop_items()
    for item in desktop_items.values():
        assert item.name in ['desktop_mail', 'desktop_gepi','desktop_gibii', 'desktop_ftp']

def test_profile_obj():
    profiles = permissions.get_profiles()
    adm = Set(('google', 'cartable'))

    for prof_name, prof in profiles.items():
        if prof_name == 'admin':
            l = []
            for pr in prof.rules:
                for thumb in pr.thumbs:
                    l.append(thumb.name)
            th_names = Set(l)
            assert th_names == adm

def test_baseprofiles():
    result = parser2.get_baseprofiles()
    assert result == {'profile1': ['admin', 'user']}
